[Vtigercrm-commits] [vtiger-commits] r10204 - in /vtigercrm/branches/5.0.3: Smarty/templates/Buttons_List.tpl Smarty/templates/Buttons_List1.tpl Smarty/templates/HomePage.tpl Smarty_setup.php config.template.php modules/Calendar/header.php modules/Dashboard/index.php

vtigercrm-commits at vtiger.fosslabs.com vtigercrm-commits at vtiger.fosslabs.com
Mon Feb 19 09:55:24 EST 2007


Author: saraj
Date: Mon Feb 19 07:55:12 2007
New Revision: 10204

Log:
dispaly of clock and calculator even if set to false in config.inc.php - fixed. Fixes #3018 

Modified:
    vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List.tpl
    vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List1.tpl
    vtigercrm/branches/5.0.3/Smarty/templates/HomePage.tpl
    vtigercrm/branches/5.0.3/Smarty_setup.php
    vtigercrm/branches/5.0.3/config.template.php
    vtigercrm/branches/5.0.3/modules/Calendar/header.php
    vtigercrm/branches/5.0.3/modules/Dashboard/index.php

Modified: vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List.tpl
==============================================================================
--- vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List.tpl (original)
+++ vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List.tpl Mon Feb 19 07:55:12 2007
@@ -70,22 +70,30 @@
 			<!-- Calendar Clock Calculator and Chat -->
 				<table border=0 cellspacing=0 cellpadding=5>
 				<tr>
-					{if $CATEGORY eq 'Settings' || $CATEGORY eq 'Tools' || $CATEGORY eq 'Analytics'}
-						{if $CHECK.Calendar eq 'yes'}
-						<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab=My Home Page");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td>
+						{if $CALENDAR_DISPLAY eq 'true'} 
+ 		                                                {if $CATEGORY eq 'Settings' || $CATEGORY eq 'Tools' || $CATEGORY eq 'Analytics'} 
+ 		                                                        {if $CHECK.Calendar eq 'yes'} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab=My Home Page");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td> 
+ 		                                                        {else} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td> 
+ 		                                                        {/if} 
 						{else}
-						<td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td>
-						{/if}
-					{else}
-						{if $CHECK.Calendar eq 'yes'}
-						<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab={$CATEGORY}");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td>
-						{else}
-						<td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td>
+						{if $CHECK.Calendar eq 'yes'} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab={$CATEGORY}");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td> 
+ 		                                                        {else} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td> 
+ 		                                                        {/if} 
 						{/if}
 					{/if}
-					<td style="padding-right:0px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td>
-					<td style="padding-right:0px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td>
-					<td style="padding-right:10px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a>
+					{if $WORLD_CLOCK_DISPLAY eq 'true'} 
+ 		                                                <td style="padding-right:0px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td> 
+ 		                                        {/if} 
+ 		                                        {if $CALCULATOR_DISPLAY eq 'true'} 
+ 		                                                <td style="padding-right:0px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td> 
+ 		                                        {/if} 
+ 		                                        {if $CHAT_DISPLAY eq 'true'} 
+ 		                                                <td style="padding-right:10px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a> 
+ 		                                        {/if} 
                     </td>	
 					<td style="padding-right:10px"><img src="{$IMAGE_PATH}btnL3Tracker.gif" alt="{$APP.LBL_LAST_VIEWED}" title="{$APP.LBL_LAST_VIEWED}" border=0 onClick="fnvshobj(this,'tracker');">
                     			</td>	

Modified: vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List1.tpl
==============================================================================
--- vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List1.tpl (original)
+++ vtigercrm/branches/5.0.3/Smarty/templates/Buttons_List1.tpl Mon Feb 19 07:55:12 2007
@@ -71,23 +71,31 @@
 			<!-- Calendar Clock Calculator and Chat -->
 				<table border=0 cellspacing=0 cellpadding=5>
 				<tr>
-					{if $CATEGORY eq 'Settings' || $CATEGORY eq 'Tools' || $CATEGORY eq 'Analytics'}
-						{if $CHECK.Calendar eq 'yes'}
-						<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab=My Home Page");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td>
+					{if $CALENDAR_DISPLAY eq 'true'} 
+ 		                                                {if $CATEGORY eq 'Settings' || $CATEGORY eq 'Tools' || $CATEGORY eq 'Analytics'} 
+ 		                                                        {if $CHECK.Calendar eq 'yes'} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab=My Home Page");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td> 
 						{else}
                                                 <td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td>
                                                 {/if}
 					{else}
-						{if $CHECK.Calendar eq 'yes'}
-						<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab={$CATEGORY}");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td>
-						{else}
-                                                <td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td>
-                                                {/if}
+						{if $CHECK.Calendar eq 'yes'} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab={$CATEGORY}");'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td> 
+ 		                                                        {else} 
+ 		                                                                <td style="padding-right:0px;padding-left:10px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif"></td> 
+								{/if}
+ 		                               {/if} 
 					{/if}
-					<td style="padding-right:0px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td>
-					<td style="padding-right:0px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td>
-					<td style="padding-right:0px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a>
-                    </td>	
+					<!--{if $WORLD_CLOCK_DISPLAY eq 'true'}--> 
+ 		                                                <td style="padding-right:0px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td> 
+ 		                                        <!--{/if}--> 
+ 		                                        {if $CALCULATOR_DISPLAY eq 'true'} 
+ 		                                                <td style="padding-right:0px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td> 
+ 		                                        {/if} 
+ 		                                        {if $CHAT_DISPLAY eq 'true'} 
+ 		                                                <td style="padding-right:0px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a> 
+ 		                                        {/if} 
+				</td>
 					<td style="padding-right:10px"><img src="{$IMAGE_PATH}btnL3Tracker.gif" alt="{$APP.LBL_LAST_VIEWED}" title="{$APP.LBL_LAST_VIEWED}" border=0 onClick="fnvshobj(this,'tracker');">
                     			</td>	
 				</tr>

Modified: vtigercrm/branches/5.0.3/Smarty/templates/HomePage.tpl
==============================================================================
--- vtigercrm/branches/5.0.3/Smarty/templates/HomePage.tpl (original)
+++ vtigercrm/branches/5.0.3/Smarty/templates/HomePage.tpl Mon Feb 19 07:55:12 2007
@@ -71,14 +71,22 @@
 					<td class="small">
 							<table border=0 cellspacing=0 cellpadding=5>
 								<tr>
-									{if $CHECK.Calendar eq 'yes'}
-									<td style="padding-right:5px;padding-left:5px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal();'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td>
-									{else}
-									<td style="padding-right:5px;padding-left:5px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif" border=0></td>
+									{if $CALENDAR_DISPLAY eq 'true'} 
+ 		                                                                              {if $CHECK.Calendar eq 'yes'} 
+ 		                                                                                        <td style="padding-right:5px;padding-left:5px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal();'><img src="{$IMAGE_PATH}btnL3Calendar.gif" alt="{$APP.LBL_CALENDAR_ALT}" title="{$APP.LBL_CALENDAR_TITLE}" border=0></a></a></td> 
+ 		                                                                              {else} 
+ 		                                                                                        <td style="padding-right:5px;padding-left:5px;"><img src="{$IMAGE_PATH}btnL3Calendar-Faded.gif" border=0></td> 
+ 		                                                                              {/if} 
 									{/if}
-									<td style="padding-right:5px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td>
-									<td style="padding-right:5px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td>
-									<td style="padding-right:5px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a></td>	
+									 {if $WORLD_CLOCK_DISPLAY eq 'true'} 
+ 		                                                                                <td style="padding-right:5px"><a href="javascript:;"><img src="{$IMAGE_PATH}btnL3Clock.gif" alt="{$APP.LBL_CLOCK_ALT}" title="{$APP.LBL_CLOCK_TITLE}" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td> 
+ 		                                                         {/if} 
+ 		                                                                        {if $CALCULATOR_DISPLAY eq 'true'} 
+ 		                                                                                <td style="padding-right:5px"><a href="#"><img src="{$IMAGE_PATH}btnL3Calc.gif" alt="{$APP.LBL_CALCULATOR_ALT}" title="{$APP.LBL_CALCULATOR_TITLE}" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td> 
+ 		                                                                        {/if} 
+ 		                                                                        {if $CHAT_DISPLAY eq 'true'} 
+ 		                                                                                <td style="padding-right:5px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="{$IMAGE_PATH}tbarChat.gif" alt="{$APP.LBL_CHAT_ALT}" title="{$APP.LBL_CHAT_TITLE}" border=0></a></td>     
+ 		                                                                        {/if} 
 									<td style="padding-right:5px"><img src="{$IMAGE_PATH}btnL3Tracker.gif" alt="{$APP.LBL_LAST_VIEWED}" title="{$APP.LBL_LAST_VIEWED}" border=0 onClick="fnvshobj(this,'tracker');"></td>
 								</tr>
 							</table>

Modified: vtigercrm/branches/5.0.3/Smarty_setup.php
==============================================================================
--- vtigercrm/branches/5.0.3/Smarty_setup.php (original)
+++ vtigercrm/branches/5.0.3/Smarty_setup.php Mon Feb 19 07:55:12 2007
@@ -16,6 +16,8 @@
 	*/
 	function vtigerCRM_Smarty()
 	{
+		global $CALENDAR_DISPLAY, $WORLD_CLOCK_DISPLAY, $CALCULATOR_DISPLAY, $CHAT_DISPLAY;
+
 		$this->Smarty();
 		$this->template_dir = 'Smarty/templates';
 		$this->compile_dir = 'Smarty/templates_c';
@@ -24,6 +26,10 @@
 
 		//$this->caching = true;
 	        //$this->assign('app_name', 'Login');
+		$this->assign('CALENDAR_DISPLAY', $CALENDAR_DISPLAY); 
+ 		$this->assign('WORLD_CLOCK_DISPLAY', $WORLD_CLOCK_DISPLAY); 
+ 		$this->assign('CALCULATOR_DISPLAY', $CALCULATOR_DISPLAY); 
+ 		$this->assign('CHAT_DISPLAY', $CHAT_DISPLAY);
 	}
 }
 

Modified: vtigercrm/branches/5.0.3/config.template.php
==============================================================================
--- vtigercrm/branches/5.0.3/modules/Calendar/header.php (original)
+++ vtigercrm/branches/5.0.3/modules/Calendar/header.php Mon Feb 19 07:55:12 2007
@@ -11,6 +11,7 @@
 require_once('include/utils/CommonUtils.php');
 $category = getParentTab();
 global $theme,$app_strings,$mod_strings;
+global $CALENDAR_DISPLAY, $WORLD_CLOCK_DISPLAY, $CALCULATOR_DISPLAY, $CHAT_DISPLAY;
 
 $theme_path="themes/".$theme."/";
 $image_path=$theme_path."images/";
@@ -41,11 +42,19 @@
 
 				<table border=0 cellspacing=0 cellpadding=5>
 
-				<tr>
-					<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick=\'fnvshobj(this,"miniCal");getMiniCal("parenttab='.$category.'");\'><img src="'.$image_path.'btnL3Calendar.gif" alt="'.$app_strings['LBL_CALENDAR_ALT'].'" title="'.$app_strings['LBL_CALENDAR_TITLE'].'" border=0></a></a></td>
-					<td style="padding-right:0px"><a href="javascript:;"><img src="'.$image_path.'btnL3Clock.gif" alt="'.$app_strings['LBL_CLOCK_ALT'].'" title="'.$app_strings['LBL_CLOCK_TITLE'].'" border=0 onClick="fnvshobj(this,\'wclock\');"></a></a></td>
-					<td style="padding-right:0px"><a href="#"><img src="'.$image_path.'btnL3Calc.gif" alt="'.$app_strings['LBL_CALCULATOR_ALT'].'" title="'.$app_strings['LBL_CALCULATOR_TITLE'].'" border=0 onClick="fnvshobj(this,\'calculator_cont\');fetch_calc();"></a></td>
-					<td style="padding-right:10px"><a href="javascript:;" onClick=\'return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");\'><img src="'.$image_path.'tbarChat.gif" alt="'.$app_strings['LBL_CHAT_ALT'].'" title="'.$app_strings['LBL_CHAT_TITLE'].'" border=0></a></td>
+					<tr>'; 
+ 		 
+ 		 
+ 		if($CALENDAR_DISPLAY == 'true') 
+ 		        $html_string .= '               <td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick=\'fnvshobj(this,"miniCal");getMiniCal("parenttab='.$category.'");\'><img src="'.$image_path.'btnL3Calendar.gif" alt="'.$app_strings['LBL_CALENDAR_ALT'].'" title="'.$app_strings['LBL_CALENDAR_TITLE'].'" border=0></a></a></td>'; 
+ 		if($WORLD_CLOCK_DISPLAY == 'true') 
+ 		        $html_string .= '               <td style="padding-right:0px"><a href="javascript:;"><img src="'.$image_path.'btnL3Clock.gif" alt="'.$app_strings['LBL_CLOCK_ALT'].'" title="'.$app_strings['LBL_CLOCK_TITLE'].'" border=0 onClick="fnvshobj(this,\'wclock\');"></a></a></td>'; 
+ 		if($CALCULATOR_DISPLAY == 'true') 
+ 		        $html_string .= '               <td style="padding-right:0px"><a href="#"><img src="'.$image_path.'btnL3Calc.gif" alt="'.$app_strings['LBL_CALCULATOR_ALT'].'" title="'.$app_strings['LBL_CALCULATOR_TITLE'].'" border=0 onClick="fnvshobj(this,\'calculator_cont\');fetch_calc();"></a></td>'; 
+ 		if($CHAT_DISPLAY == 'true') 
+ 		        $html_string .= '               <td style="padding-right:10px"><a href="javascript:;" onClick=\'return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");\'><img src="'.$image_path.'tbarChat.gif" alt="'.$app_strings['LBL_CHAT_ALT'].'" title="'.$app_strings['LBL_CHAT_TITLE'].'" border=0></a></td>'; 
+ 		 
+ 		$html_string .= ' 
 					<td style="padding-right:10px"><img src="'.$image_path.'btnL3Tracker.gif" alt="'.$app_strings['LBL_LAST_VIEWED'].'" title="'.$app_strings['LBL_LAST_VIEWED'].'" border=0 onClick="fnvshobj(this,\'tracker\');"></td>
 				</tr>
 				</table>

Modified: vtigercrm/branches/5.0.3/modules/Dashboard/index.php
==============================================================================
--- vtigercrm/branches/5.0.3/modules/Dashboard/index.php (original)
+++ vtigercrm/branches/5.0.3/modules/Dashboard/index.php Mon Feb 19 07:55:12 2007
@@ -99,10 +99,28 @@
 				<table border=0 cellspacing=0 cellpadding=5>
 
 				<tr>
+<?php 
+if($CALENDAR_DISPLAY == 'true') { 
+?> 
 					<td style="padding-right:0px;padding-left:10px;"><a href="javascript:;" onClick='fnvshobj(this,"miniCal");getMiniCal("parenttab=My Home Page");'><img src="<?php echo $image_path;?>btnL3Calendar.gif" alt="<?php echo $app_strings['LBL_CALENDAR_ALT']; ?>" title="<?php echo $app_strings['LBL_CALENDAR_TITLE']; ?>" border=0></a></a></td>
+<?php 
+} 
+if($WORLD_CLOCK_DISPLAY == 'true') { 
+?> 
 					<td style="padding-right:0px"><a href="javascript:;"><img src="<?php echo $image_path;?>btnL3Clock.gif" alt="<?php echo $app_strings['LBL_CLOCK_ALT']; ?>" title="<?php echo $app_strings['LBL_CLOCK_TITLE']; ?>" border=0 onClick="fnvshobj(this,'wclock');"></a></a></td>
+<?php 
+} 
+if($CALCULATOR_DISPLAY == 'true') { 
+?>
 					<td style="padding-right:0px"><a href="#"><img src="<?php echo $image_path;?>btnL3Calc.gif" alt="<?php echo $app_strings['LBL_CALCULATOR_ALT']; ?>" title="<?php echo $app_strings['LBL_CALCULATOR_TITLE']; ?>" border=0 onClick="fnvshobj(this,'calculator_cont');fetch_calc();"></a></td>
-					<td style="padding-right:10px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="<?php echo $image_path;?>tbarChat.gif" alt="<?php echo $app_strings['LBL_CHAT_ALT']; ?>" title="<?php echo $app_strings['LBL_CHAT_TITLE']; ?>" border=0></a>
+<?php 
+} 
+if($CHAT_DISPLAY == 'true') { 
+?> 		
+			<td style="padding-right:10px"><a href="javascript:;" onClick='return window.open("index.php?module=Contacts&action=vtchat","Chat","width=600,height=450,resizable=1,scrollbars=1");'><img src="<?php echo $image_path;?>tbarChat.gif" alt="<?php echo $app_strings['LBL_CHAT_ALT']; ?>" title="<?php echo $app_strings['LBL_CHAT_TITLE']; ?>" border=0></a>
+<?php 
+} 
+?> 
                     </td>	
 				</tr>
 				</table>





More information about the vtigercrm-commits mailing list
--- vtigercrm/branches/5.0.3/config.template.php (original)
+++ vtigercrm/branches/5.0.3/config.template.php Mon Feb 19 07:55:12 2007
@@ -19,12 +19,12 @@
 // memory limit default value = 64M
 ini_set('memory_limit','64M');
 
-// show or hide world clock, calculator and FCKEditor
-// world_clock_display default value = true
-// calculator_display default value = true
-// fckeditor_display default value = true
+// show or hide calendar, world clock, calculator, chat and FCKEditor 
+// Do NOT remove the quotes if you set these to false! 
+$CALENDAR_DISPLAY = 'true';
 $WORLD_CLOCK_DISPLAY = 'true';
 $CALCULATOR_DISPLAY = 'true';
+$CHAT_DISPLAY = 'true'; 
 $FCKEDITOR_DISPLAY = 'true';
 
 // url for customer portal (Example: http://vtiger.com/portal)

Modified: vtigercrm/branches/5.0.3/modules/Calendar/header.php
==============================================================================